
'''
Set TCPIP v1.0
by wrybread@gmail.com
March 16, 2007

Sets Windows TCP/IP parameters from commandline.

Written in Python 2.4, but should work fine with later versions.

Requires to WMI module, which you can get here:
http://tgolden.sc.sabren.com/python/wmi.html



To do:

- add the ability to set DNS to DHCP. Use a netsh command?

- add the ability to refer to a NIC by name?



Instructions:

See the readme for lots of usage notes etc.

The gist is:

set_tcpip.exe ip=192.168.1.10 subnet=255.255.255.0 gateway=192.168.1.1 dns=192.168.1.1,66.6.6.6 adaptor=1

'''





import wmi # http://tgolden.sc.sabren.com/python/wmi.html

import sys


def get_commandline_parameters():

    # Note the colon, that puts it all in an array
    commandline_arr = sys.argv[1:]

    for x in commandline_arr:

        if "dns=" in x:
            dns = x.replace("dns=", "")
            dns_arr = dns.split(",")

        if "gateway=" in x:
            gateway = x.replace("gateway=", "")

        if "ip=" in x:
            ip = x.replace("ip=", "")

        if "subnet=" in x:
            subnet = x.replace("subnet=", "")

        if "adaptor=" in x:
            adaptor = x.replace("adaptor=", "")
            adaptor = int(adaptor)
            adaptor = adaptor - 1

        if "help" in x or "?" in x:
            help_message = "\nBy wrybread@gmail.com\nSee wrybread.com/utilities for detailed instructions, but here's the gist.\n\nUsage:\nset_tcpip.exe ip=192.168.1.10 subnet=255.255.255.0 gateway=192.168.1.1 dns=192.168.1.1,66.6.6.6\nAll parameters optional and can appear in any order.\nNo spaces within the parameters!\nIf you omit subnet mask it defaults to 255.255.255.0.\nYou can also make things dynamic like this:\nset_tcpip.exe ip=dynamic"
            print help_message
            
    try: dns_arr
    except NameError: dns_arr = None

    try: gateway
    except NameError: gateway = None

    try: ip
    except NameError: ip = None

    try: subnet
    except NameError: subnet = None

    try: adaptor
    except NameError: adaptor = 0
    
    return gateway, dns_arr, ip, subnet, adaptor

        
parameters = get_commandline_parameters()

# Make our variables easier to read:
gateway = parameters[0]
dns = parameters[1]
ip = parameters[2]
subnet = parameters[3]
adaptor = parameters[4]

#gateway = "192.168.2.4"
#dns = ["192.168.2.4"]

# Create our WMI object:
c = wmi.WMI ()


try:
    nic = c.Win32_NetworkAdapterConfiguration (IPEnabled=True)[adaptor]
except IndexError:
    print "\nWhoops! You don't have a network adaptor " + `adaptor + 1` + " installed!"
    gateway = None
    ip = None
    dns = None
    
    

# Spacer
print ""

# Adjust it so it looks nicer for our status messages
adaptor = adaptor + 1

# DHCP for gateway and ip (these become dynamic together)
if gateway == "dynamic" or ip == "dynamic":

    gateway = None
    ip = None
    
    print "Setting the gateway, IP and subnet mask of NIC adaptor " + `adaptor` + " to dynamic"
    result = nic.EnableDHCP()

    if result[0] == 0:
        print "Successfully set the gateway, IP and subnet of NIC adaptor " + `adaptor` + " to dynamic\n"
    if result[0] == 1:
        print "Successfully set the gateway, IP and subnet of NIC adaptor " + `adaptor` + " to dynamic but a reboot may be required\n"
    if result[0] != 0 and result[0] != 1:
        print "Failed to set the gateway, IP and subnet of NIC adaptor " + `adaptor` + "!\n"



# Gateway  
if gateway:

    print "Setting the gateway to " + gateway
    result = nic.SetGateways (DefaultIPGateway=[gateway], GatewayCostMetric=["20"])

    if result[0] == 0:
        print "Successfully set the gateway of NIC adaptor " + `adaptor` + "\n"
    if result[0] == 1:
        print "Successfully set the gateway of NIC adaptor " + `adaptor` + " but a reboot may be required\n"
    if result[0] != 0 and result[0] != 1:
        print "Failed to set the gateway of NIC adaptor " + `adaptor` + "!\n"


# DNS
if dns:

    print "Setting the DNS servers of NIC adaptor " + `adaptor` + " to " + `dns`
    result = nic.SetDNSServerSearchOrder (DNSServerSearchOrder = dns)
        
    if result[0] == 0:
        print "Successfully set the DNS servers of NIC adaptor " + `adaptor` + "\n"
    if result[0] == 1:
        print "Successfully set the DNS servers of NIC adaptor " + `adaptor` + " but a reboot may be required\n"
    if result[0] != 0 and result[0] != 1:
        print "Failed to set the DNS servers of NIC adaptor " + `adaptor` + "!\n"


# IP
if ip:

    # make our subnet mask 255.255.255.0 unless otherwise specified
    if subnet:
        subnet = subnet
    else:
        subnet = "255.255.255.0"
        
    print "Setting the IP address of NIC adaptor " + `adaptor` + " to " + ip + " and the subnet mask to " + subnet
    result = nic.EnableStatic(IPAddress= [ip], SubnetMask=[subnet])

    if result[0] == 0:
        print "Successfully set the IP address and subnet mask of NIC adaptor " + `adaptor` + "\n"
    if result[0] == 1:
        print "Successfully set the IP address and subnet mask of NIC adaptor " + `adaptor` + " but a reboot may be required\n"
    if result[0] != 0 and result[0] != 1:
        print "Failed to set the IP address and subnet mask of NIC adaptor " + `adaptor` + "!\n"




